## Changelog 

### Removed

- [alpha] `cdf dump assets/timeseries/event/files-metadata` commands.
These have been replaced by `cdf data download
assets/timeseries/events/files`. Note this removal only occurs if the
alpha flag `v07` is set to `true`.